@@ -36,11 +36,7 @@
 #include "vid_aux.h"
 // FIXME
 #undef EMULATE_FAST_INT
-#if HAVE_LIBAVCODEC_AVCODEC_H
 #include <libavcodec/avcodec.h>
-#else
-#include <ffmpeg/avcodec.h>
-#endif
 
 #if !defined(INFINITY) && defined(HUGE_VAL)
 #define INFINITY HUGE_VAL
@@ -804,8 +800,10 @@ MOD_init
     lavc_venc_context->luma_elim_threshold= lavc_param_luma_elim_threshold;
     lavc_venc_context->chroma_elim_threshold= lavc_param_chroma_elim_threshold;
     lavc_venc_context->rtp_payload_size   = lavc_param_packet_size;
+#if LIBAVCODEC_VERSION_INT < ((52<<16)+(0<<8)+0)
     if (lavc_param_packet_size)
         lavc_venc_context->rtp_mode       = 1;
+#endif
     lavc_venc_context->strict_std_compliance= lavc_param_strict;
     lavc_venc_context->i_quant_factor     = lavc_param_vi_qfactor;
     lavc_venc_context->i_quant_offset     = lavc_param_vi_qoffset;
@@ -1003,7 +1001,11 @@ MOD_init
     lavc_venc_context->flags |= lavc_param_gmc;
     lavc_venc_context->flags |= lavc_param_closedgop;
     lavc_venc_context->flags |= lavc_param_trunc;
+#if LIBAVCODEC_VERSION_INT < ((52<<16)+(0<<8)+0)
     lavc_venc_context->flags |= lavc_param_trell;
+#else
+    lavc_venc_context->trellis = lavc_param_trell;
+#endif
     lavc_venc_context->flags |= lavc_param_aic;
     lavc_venc_context->flags |= lavc_param_umv;
     lavc_venc_context->flags |= lavc_param_v4mv;
